# m5meta - M5 Meta Assembler

Copyright 2019 Eric Smith <spacewar@gmail.com>

m5meta development is hosted at the
[m5meta Github repository](https://github.com/brouhaha/m5meta/).

## Introduction

m5meta is a simple meta assembler intended for use assembling microcode
for horizontally microcoded machines.
